dsa_config provides the following functions:
- Config a DSC server with a default media server, AWS S3 storage and create a target group for this storage.
- Register and enable a Teradata System.

dsa_rest provides modules for following functions:
-  Get available media servers in DSC
- Configure AWS.
- Create S3 target group.
- Configure a Teradata database system.
- Create media server
- Enable Teradata database system.
- Get the list of Teradata database systems registered with DSC.
